@@ -103,7 +103,7 @@ AF_UNIX = getattr(socket, "AF_UNIX", None)
 PYTHON = os.path.realpath(sys.executable)
 DEVNULL = open(os.devnull, 'r+')
 
-TESTFILE_PREFIX = '$psutil'
+TESTFILE_PREFIX = '$testfn'
 TESTFN = os.path.join(os.path.realpath(os.getcwd()), TESTFILE_PREFIX)
 _TESTFN = TESTFN + '-internal'
 TESTFN_UNICODE = TESTFN + "-ƒőő"
@@ -485,6 +485,15 @@ def safe_rmpath(path):
             raise
 
 
+def safe_mkdir(dir):
+    "Convenience function for creating a directory"
+    try:
+        os.mkdir(dir)
+    except OSError as err:
+        if err.errno != errno.EEXIST:
+            raise
+
+
 @contextlib.contextmanager
 def chdir(dirname):
     "Context manager which temporarily changes the current directory."
